---
finished: "2024-01-02"
started: "2023-03-29"
made with:
    - docopt
    - python
tags:
    - automation
    - program
    - command-line
---

# issurge


:: en

![](../demo.mp4 "Demo video")

A small CLI tool to easily submit plenty of issues from a text file. Useful when you get a feedback document from a client

[Sur GitHub](https://github.com/ewen-lbh/issurge.git)

:: fr

![](../demo.mp4 "Vidéo de démonstration")

Un petit outil en ligne de commande pour soumettre facilement beaucoup de problèmes à partir d'un fichier texte. Utile lorsque l'on reçoit un document de feedback d'un client

[On GitHub](https://github.com/ewen-lbh/issurge.git)
